@@ -20,7 +20,8 @@ class Entity(object):
         self.types = self.root.types
         if self.root.uri:
             self.uri = self.root.uri
-        self.root.add_triple("dcterms:requires", manifest_uri)
+        if manifest_uri:
+            self.root.add_triple("dcterms:requires", manifest_uri)
         self.manifest = Manifest(manifest_uri)
         
     def add_namespaces(self, ns_dict):
@@ -79,7 +80,13 @@ class Entity(object):
         return g.serialize(format=format, encoding="utf-8")
 
     def from_string(self, root_uri, rdfstring, format="xml"):
-        pass
+        t = TextInputSource(rdfstring)
+        g = ConjunctiveGraph()
+        g = g.parse(t, format)
+        for prefix, ns in g.namespaces():
+            self.add_namespace(prefix ,ns)
+        for s,p,o in g.triples((None, None, None)):
+            self.add_triple(s,p,o)
 
     def namedgraphid_to_uri(self, graph_id):
         return "%s/%s" % (self.uri, graph_id)
