@@ -212,9 +212,10 @@ class RDFobject(object):
         return self.to_string('xml')
     
     def to_string(self, format="xml"):
-        if self.altered or self._cached == False:
-            self.altered = False
-            self._cached = self.get_graph()
-        return self._cached.serialize(format=format, encoding="utf-8")
+#        if self.altered or self._cached == False:
+#            self.altered = False
+#            self._cached = self.get_graph()
+#        return self._cached.serialize(format=format, encoding="utf-8")
+        return self.get_graph().serialize(format=format, encoding="utf-8")
         
 
