@@ -265,7 +265,7 @@ class FileStorageClient(object):
         part_name = "%s%s%s" % (part_id, self.prefix, version)
         r = RDFobject()
         r.set_uri(self.uri_base[id])
-        if version > 1:
+        if version >= 1:
             f = self.storeclient.get_stream(id, part_id, part_name,streamable=False)
             r.from_string(self.uri_base[id], f.decode('utf-8'))
         return r
@@ -277,7 +277,7 @@ class FileStorageClient(object):
             version = self._get_latest_part(id, part_id)
         part_name = "%s%s%s" % (part_id, self.prefix, version)
         m = Manifest(file_uri)
-        if version > 1:
+        if version >= 1:
             f = self.storeclient.get_stream(id, part_id, part_name,streamable=False)
             m.from_string(f.decode('utf-8'))
         return m
@@ -298,6 +298,12 @@ class FileStorageClient(object):
             self._log(id, 'c', 'Creating an object')
         return FileStorageObject(id, self)
 
+    def deleteObject(self, id):
+        if self.storeclient.exists(id):
+            self.storeclient.delete_object(id)
+            if self.queue != None:
+                self._log(id, 'd', 'Deleting an object')
+
     def _log(self, id, action, label, **kw):
         msg = {}
         msg.update(kw)
