@@ -29,7 +29,7 @@ class FakeQueue(object):
 
 fq = FakeQueue()
 
-f = FileEntityFactory(uri_base=u"info:fedora/", queue=fq, storage_dir="deptentitytest", prefix="_")
+f = FileEntityFactory(uri_base=u"info:fedora/", queue=fq, storage_dir="deptentitytest", prefix="_", context = {'store_name':'groups'})
 
 uri=u"info:fedora/ora:1"
 
