@@ -59,6 +59,11 @@ vid.del_stream('deleteall')
 
 print vid
 
+# Restoring from disc
+loaded_vid = foo.get_id('video:1')
+
+print loaded_vid
+
 print "Parts: %s" % vid.list_parts()
 
 print "Deleteme Parts: %s" % vid.list_part_versions('deleteme')
